'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

require('react');
var PropTypes = require('prop-types');
var react = require('@emotion/react');
require('@babel/runtime/helpers/extends');
require('../icon/index.cjs');
var chevronIcon = require('../../icons/icons/chevronIcon.cjs');
var style = require('./style.cjs');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);

var Dropdown = _ref => {
  var {
    borderRadius,
    id,
    onChange,
    onDropdownContainerFocus,
    options,
    textAlign = 'left',
    value,
    ariaLabel
  } = _ref;
  var theme = react.useTheme();
  var touchSupported = ('ontouchstart' in document.documentElement);

  var onSelectChange = event => {
    var {
      target
    } = event;
    var {
      selectedIndex,
      selectedOptions
    } = target;
    var selectedOption = options[selectedIndex];

    if (selectedOptions.length) {
      onChange(selectedOption);
    }
  };

  var handleOnDropdownContainerFocus = event => {
    if (onDropdownContainerFocus) {
      onDropdownContainerFocus(event);
    }
  };

  return react.jsx(style["default"].DropdownContainer, {
    textAlign: textAlign
  }, react.jsx("select", {
    css: style["default"].dropdownInputStyle({
      borderRadius: borderRadius !== null && borderRadius !== void 0 ? borderRadius : theme.BORDER_RADIUS.small,
      shouldBeFullyRounded: true,
      textAlign,
      theme
    }),
    id: id,
    value: value !== null && value !== void 0 ? value : '',
    "aria-label": ariaLabel,
    onChange: onSelectChange,
    onFocus: handleOnDropdownContainerFocus
  }, options.map((option, index) => {
    var _option$value;

    var isDisabled = option.disabled;
    /*
     * We use touchSupported to prevent setting the default value to disabled
     */

    if (option.value === value && touchSupported) {
      isDisabled = false;
    }

    return react.jsx("option", {
      key: (_option$value = option.value) !== null && _option$value !== void 0 ? _option$value : "undefined-".concat(index),
      value: option.value,
      disabled: isDisabled
    }, option.label);
  })), react.jsx(style["default"].IconContainer, null, react.jsx(chevronIcon["default"], {
    width: 15,
    height: 15
  })));
};
Dropdown.propTypes = {
  ariaLabel: PropTypes__default["default"].string,
  borderRadius: PropTypes__default["default"].string,
  id: PropTypes__default["default"].string,
  onChange: PropTypes__default["default"].func.isRequired,
  options: PropTypes__default["default"].arrayOf(PropTypes__default["default"].shape({
    value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].string, PropTypes__default["default"].number]),
    label: PropTypes__default["default"].string.isRequired,
    disabled: PropTypes__default["default"].bool
  }).isRequired).isRequired,
  textAlign: PropTypes__default["default"].oneOf(['left', 'center']),
  value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].string, PropTypes__default["default"].number])
};

exports.Dropdown = Dropdown;
