import React from 'react';
import PropTypes from 'prop-types';
export declare type OptionValue = string | number;
export interface OptionType {
    disabled?: boolean;
    /**
     * The text to be displayed for the option
     */
    label: string;
    /**
     * The option indentifier
     */
    value?: OptionValue;
    /**
     * Any other data we want to pass from options
     */
    [key: string]: unknown;
}
interface DropdownProps<T> {
    /**
     * An optional prop to allow for the select to have an aria-label attribute added for applications where a standalone label isn't ideal.
     */
    ariaLabel?: string | undefined;
    borderRadius?: string;
    /**
     * ID for label associated control
     */
    id?: string;
    /**
     * The handler to be invoked on option change
     */
    onChange: (option: T) => void;
    /**
     * The handler to be invoked on focus
     */
    onDropdownContainerFocus?: (event?: React.FocusEvent) => void;
    options: T[];
    textAlign?: 'left' | 'center';
    /**
     * The currently selected option
     */
    value?: OptionValue;
}
/**
 * `<Dropdown />` is a controlled component and should be wrapped by a parent to control the dropdown's state.
 * This ships with a mobile-friendly implementation that will handle mobile devices automatically.
 */
export declare const Dropdown: {
    <T extends OptionType>({ borderRadius, id, onChange, onDropdownContainerFocus, options, textAlign, value, ariaLabel, }: DropdownProps<T>): JSX.Element;
    propTypes: {
        ariaLabel: PropTypes.Requireable<string>;
        borderRadius: PropTypes.Requireable<string>;
        id: PropTypes.Requireable<string>;
        onChange: PropTypes.Validator<(...args: any[]) => any>;
        options: PropTypes.Validator<PropTypes.InferProps<{
            value: PropTypes.Requireable<string | number>;
            label: PropTypes.Validator<string>;
            disabled: PropTypes.Requireable<boolean>;
        }>[]>;
        textAlign: PropTypes.Requireable<string>;
        value: PropTypes.Requireable<string | number>;
    };
};
export {};
//# sourceMappingURL=index.d.ts.map